"use strict";
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const workspace_1 = require("./workspace");
const TEST_WORKSPACE_CONTENT = JSON.stringify({
    version: 1,
    projects: {
        test: {
            root: '',
        },
    },
});
function testRule(rule, tree) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, schematics_1.callRule)(rule, tree, {}).toPromise();
    });
}
describe('readWorkspace', () => {
    it('reads a workspace using the default path value', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        tree.create('/angular.json', TEST_WORKSPACE_CONTENT);
        const workspace = yield (0, workspace_1.getWorkspace)(tree);
        expect(workspace.projects.has('test')).toBeTrue();
    }));
    it('reads a workspace when specifying a directory path', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        tree.create('/xyz/angular.json', TEST_WORKSPACE_CONTENT);
        const workspace = yield (0, workspace_1.getWorkspace)(tree, '/xyz/');
        expect(workspace.projects.has('test')).toBeTrue();
    }));
    it('reads a workspace when specifying a file path', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        tree.create('/xyz/angular.json', TEST_WORKSPACE_CONTENT);
        const workspace = yield (0, workspace_1.getWorkspace)(tree, '/xyz/angular.json');
        expect(workspace.projects.has('test')).toBeTrue();
    }));
    it('throws if workspace file does not exist when using the default path value', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        yield expectAsync((0, workspace_1.getWorkspace)(tree)).toBeRejectedWithError();
    }));
    it('throws if workspace file does not exist when specifying a file path', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        tree.create('/angular.json', TEST_WORKSPACE_CONTENT);
        yield expectAsync((0, workspace_1.getWorkspace)(tree, 'abc.json')).toBeRejectedWithError();
    }));
});
describe('writeWorkspace', () => {
    it('writes a workspace using the default path value', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        tree.create('/angular.json', TEST_WORKSPACE_CONTENT);
        const workspace = yield (0, workspace_1.getWorkspace)(tree);
        workspace.extensions['x-abc'] = 1;
        yield (0, workspace_1.writeWorkspace)(tree, workspace);
        expect(tree.readJson('/angular.json')).toEqual(jasmine.objectContaining({ 'x-abc': 1 }));
    }));
    it('writes a workspace when specifying a path', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        tree.create('/angular.json', TEST_WORKSPACE_CONTENT);
        const workspace = yield (0, workspace_1.getWorkspace)(tree);
        workspace.extensions['x-abc'] = 1;
        yield (0, workspace_1.writeWorkspace)(tree, workspace, '/xyz/angular.json');
        expect(tree.readJson('/xyz/angular.json')).toEqual(jasmine.objectContaining({ 'x-abc': 1 }));
    }));
});
describe('updateWorkspace', () => {
    it('updates a workspace using the default path value', () => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const tree = new schematics_1.EmptyTree();
        tree.create('/angular.json', TEST_WORKSPACE_CONTENT);
        const rule = (0, workspace_1.updateWorkspace)((workspace) => {
            workspace.projects.add({
                name: 'abc',
                root: 'src',
            });
        });
        yield testRule(rule, tree);
        expect((_a = tree.read('angular.json')) === null || _a === void 0 ? void 0 : _a.toString()).toContain('"abc"');
    }));
    it('throws if workspace file does not exist', () => __awaiter(void 0, void 0, void 0, function* () {
        const tree = new schematics_1.EmptyTree();
        const rule = (0, workspace_1.updateWorkspace)((workspace) => {
            workspace.projects.add({
                name: 'abc',
                root: 'src',
            });
        });
        yield expectAsync(testRule(rule, tree)).toBeRejectedWithError();
    }));
    it('allows executing a returned followup rule', () => __awaiter(void 0, void 0, void 0, function* () {
        var _b;
        const tree = new schematics_1.EmptyTree();
        tree.create('/angular.json', TEST_WORKSPACE_CONTENT);
        const rule = (0, workspace_1.updateWorkspace)(() => {
            return (tree) => tree.create('/followup.txt', '12345');
        });
        yield testRule(rule, tree);
        expect((_b = tree.read('/followup.txt')) === null || _b === void 0 ? void 0 : _b.toString()).toContain('12345');
    }));
});
//# sourceMappingURL=workspace_spec.js.map